<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr" sourcelanguage="en">
  <context>
    <name>CmdDrawingAnnotation</name>
    <message>
      <location filename="../../Command.cpp" line="+389"/>
      <source>Drawing</source>
      <translation>Mise en plan</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Annotation</source>
      <translation>&amp;Annotation</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Inserts an Annotation view in the active drawing</source>
      <translation>Insère une annotation sur la feuille active</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingClip</name>
    <message>
      <location line="+41"/>
      <source>Drawing</source>
      <translation>Mise en plan</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Clip</source>
      <translation>&amp;Masque</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Inserts a clip group in the active drawing</source>
      <translation>Insère un groupe de masquage sur la feuille active</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingExportPage</name>
    <message>
      <location line="+91"/>
      <source>File</source>
      <translation>Fichier</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Export page...</source>
      <translation>&amp;Exporter la page...</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Export a page to an SVG file</source>
      <translation>Exporter une page vers un fichier SVG</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingNewA3Landscape</name>
    <message>
      <location line="-314"/>
      <source>Drawing</source>
      <translation>Mise en plan</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Insert new A3 landscape drawing</source>
      <translation>Insère une nouvelle feuille A3 paysage</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingNewPage</name>
    <message>
      <location line="-133"/>
      <source>Drawing</source>
      <translation>Mise en plan</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Insert new drawing</source>
      <translation>Insérer une nouvelle feuille</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingNewView</name>
    <message>
      <location line="+166"/>
      <source>Drawing</source>
      <translation>Mise en plan</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert view in drawing</source>
      <translation>Insérer une vue dans la page</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert a new View of a Part in the active drawing</source>
      <translation>Insérer une nouvelle vue de la pièce dans la page active</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingOpen</name>
    <message>
      <location line="-202"/>
      <source>Drawing</source>
      <translation>Mise en plan</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open SVG...</source>
      <translation>Ouvrir SVG...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open a scalable vector graphic</source>
      <translation>Ouvrir un fichier vectoriel SVG</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingOpenBrowserView</name>
    <message>
      <location line="+294"/>
      <source>Drawing</source>
      <translation>Mise en plan</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open &amp;browser view</source>
      <translation>Vue &amp;web</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Opens the selected page in a browser view</source>
      <translation>Ouvre la feuille sélectionnée dans le navigateur web</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingOrthoViews</name>
    <message>
      <location line="-49"/>
      <source>Drawing</source>
      <translation>Mise en plan</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert orthographic views</source>
      <translation>Insérer des vues orthogonales</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Insert an orthographic projection of a part in the active drawing</source>
      <translation>Insérer une projection orthogonale d'une forme sur la feuille active</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingProjectShape</name>
    <message>
      <location line="+271"/>
      <source>Drawing</source>
      <translation>Mise en plan</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Project shape...</source>
      <translation>Projeter la forme...</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Project shape onto a user-defined plane</source>
      <translation>Projeter une forme sur un plan défini par l'utilisateur</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingSymbol</name>
    <message>
      <location line="-107"/>
      <source>Drawing</source>
      <translation type="unfinished">Mise en plan</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Symbol</source>
      <translation type="unfinished">&amp;Symbole</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Inserts a symbol from a svg file in the active drawing</source>
      <translation type="unfinished">Insère un symbole à partir d'un fichier svg dans la mise en plan active</translation>
    </message>
  </context>
  <context>
    <name>DrawingGui::DrawingView</name>
    <message>
      <location filename="../../DrawingView.cpp" line="+207"/>
      <source>&amp;Background</source>
      <translation>&amp;Arrière-plan</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>&amp;Outline</source>
      <translation>&amp;Contour</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>&amp;Native</source>
      <translation>&amp;Natif</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;OpenGL</source>
      <translation>&amp;OpenGL</translation>
    </message>
    <message>
      <location line="+3"/>
      <source>&amp;Image</source>
      <translation>&amp;Image</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;High Quality Antialiasing</source>
      <translation>Anticrénelage &amp;haute qualité</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Open SVG File</source>
      <translation>Ouvrir un fichier SVG</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Could not open file '%1'.</source>
      <translation>Impossible d'ouvrir le fichier '%1'.</translation>
    </message>
    <message>
      <location line="+24"/>
      <source>&amp;Renderer</source>
      <translation>Moteur de &amp;rendu</translation>
    </message>
    <message>
      <location line="+55"/>
      <source>Export PDF</source>
      <translation>Exporter vers PDF</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>PDF file (*.pdf)</source>
      <translation>Fichier PDF (*.pdf)</translation>
    </message>
    <message>
      <location line="+16"/>
      <source>Page sizes</source>
      <translation>Formats de papier</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>A0</source>
      <translation>A0</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>A1</source>
      <translation>A1</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>A2</source>
      <translation>A2</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>A3</source>
      <translation>A3</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>A4</source>
      <translation>A4</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>A5</source>
      <translation>A5</translation>
    </message>
  </context>
  <context>
    <name>DrawingGui::TaskOrthoViews</name>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="+26"/>
      <source>Orthographic Projection</source>
      <translation>Projection orthogonale</translation>
    </message>
    <message>
      <location line="+20"/>
      <location line="+25"/>
      <location line="+25"/>
      <location line="+25"/>
      <location line="+25"/>
      <location line="+31"/>
      <location line="+25"/>
      <location line="+25"/>
      <location line="+25"/>
      <location line="+25"/>
      <location line="+25"/>
      <location line="+60"/>
      <source>Right click for axonometric settings</source>
      <translation type="unfinished">Faites un clic droit pour les paramètres d'axonométrie</translation>
    </message>
    <message>
      <location line="+106"/>
      <source>Top left x / y</source>
      <translation type="unfinished">En haut à gauche x / y</translation>
    </message>
    <message>
      <location line="+48"/>
      <source>Spacing dx / dy   </source>
      <translation type="unfinished">Espacement dx / dy   </translation>
    </message>
    <message>
      <location line="+71"/>
      <source> Axis out and right</source>
      <translation type="unfinished"> Sens de l'axe vers la droite</translation>
    </message>
    <message>
      <location line="+7"/>
      <source> Vertical tilt</source>
      <translation type="unfinished"> Retournement vertical</translation>
    </message>
    <message>
      <location line="+11"/>
      <location line="+200"/>
      <source>X +ve</source>
      <translation type="unfinished">X +ve</translation>
    </message>
    <message>
      <location line="-195"/>
      <location line="+75"/>
      <location line="+125"/>
      <source>Y +ve</source>
      <translation type="unfinished">Y +ve</translation>
    </message>
    <message>
      <location line="-195"/>
      <location line="+75"/>
      <location line="+125"/>
      <source>Z +ve</source>
      <translation type="unfinished">Z +ve</translation>
    </message>
    <message>
      <location line="-195"/>
      <location line="+200"/>
      <source>X -ve</source>
      <translation type="unfinished">X -ve</translation>
    </message>
    <message>
      <location line="-195"/>
      <location line="+70"/>
      <location line="+130"/>
      <source>Y -ve</source>
      <translation type="unfinished">Y -ve</translation>
    </message>
    <message>
      <location line="-195"/>
      <location line="+70"/>
      <location line="+130"/>
      <source>Z -ve</source>
      <translation type="unfinished">Z -ve</translation>
    </message>
    <message>
      <location line="-188"/>
      <source>Isometric</source>
      <translation type="unfinished">Isométrique</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Dimetric</source>
      <translation type="unfinished">Dimétrique</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Trimetric</source>
      <translation type="unfinished">Trimétrique</translation>
    </message>
    <message>
      <location line="+8"/>
      <source> Scale</source>
      <translation type="unfinished"> Échelle</translation>
    </message>
    <message>
      <location line="+7"/>
      <source> View projection   </source>
      <translation type="unfinished"> Vue de projection   </translation>
    </message>
    <message>
      <location line="+7"/>
      <source> Axis aligned up</source>
      <translation type="unfinished"> Axe aligné vers le haut</translation>
    </message>
    <message>
      <location line="+41"/>
      <location line="+23"/>
      <source>Flip</source>
      <translation type="unfinished">Retourner</translation>
    </message>
    <message>
      <location line="-10"/>
      <source> Trimetric</source>
      <translation type="unfinished"> Trimétrique</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Projection</source>
      <translation>Projection</translation>
    </message>
    <message>
      <location line="+11"/>
      <source>Third Angle</source>
      <translation>américaine</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>First Angle</source>
      <translation>européenne</translation>
    </message>
    <message>
      <location line="+19"/>
      <source>View from:</source>
      <translation type="unfinished">Vue de :</translation>
    </message>
    <message>
      <location line="+47"/>
      <source>Axis aligned right:</source>
      <translation type="unfinished">Axe aligné à droite :</translation>
    </message>
    <message>
      <source>Primary View</source>
      <translation type="obsolete">Vue principale</translation>
    </message>
    <message>
      <source>Front</source>
      <translation type="obsolete">Frontal</translation>
    </message>
    <message>
      <source>Right</source>
      <translation type="obsolete">Droit</translation>
    </message>
    <message>
      <source>Back</source>
      <translation type="obsolete">Arrière</translation>
    </message>
    <message>
      <source>Left</source>
      <translation type="obsolete">Gauche</translation>
    </message>
    <message>
      <source>Top</source>
      <translation type="obsolete">Dessus</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation type="obsolete">Dessous</translation>
    </message>
    <message>
      <source>- Rotate</source>
      <translation type="obsolete">-Faire pivoter</translation>
    </message>
    <message>
      <source>90</source>
      <translation type="obsolete">90</translation>
    </message>
    <message>
      <source>180</source>
      <translation type="obsolete">180</translation>
    </message>
    <message>
      <source>270</source>
      <translation type="obsolete">270</translation>
    </message>
    <message>
      <location line="-514"/>
      <source>Primary view</source>
      <translation>Vue principale</translation>
    </message>
    <message>
      <location line="+16"/>
      <source>Secondary Views</source>
      <translation>Vues secondaires</translation>
    </message>
    <message>
      <location line="+72"/>
      <source>General</source>
      <translation>Général</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Auto scale / position</source>
      <translation>Échelle / position auto</translation>
    </message>
    <message>
      <location line="+15"/>
      <source>Scale</source>
      <translation>Échelle</translation>
    </message>
    <message>
      <source>Primary x / y</source>
      <translation type="obsolete">x / y principaux</translation>
    </message>
    <message>
      <source>Secondary dx / dy</source>
      <translation type="obsolete">dx et dy secondaires</translation>
    </message>
    <message>
      <location line="+125"/>
      <source>Show hidden</source>
      <translation>Monter les bords cachés</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Show smooth</source>
      <translation>Montrer les bords lissés</translation>
    </message>
    <message>
      <location line="+11"/>
      <source>Axonometric</source>
      <translation>Axonométrique</translation>
    </message>
  </context>
  <context>
    <name>DrawingGui::TaskProjection</name>
    <message>
      <location filename="../../TaskDialog.cpp" line="+49"/>
      <source>Visible sharp edges</source>
      <translation>Arêtes vives visibles</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Visible smooth edges</source>
      <translation>Arêtes de tangence visibles</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Visible sewn edges</source>
      <translation>Arêtes cousues visibles</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Visible outline edges</source>
      <translation>Arêtes de contour visibles</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Visible isoparameters</source>
      <translation>Isoparamètres visibles</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Hidden sharp edges</source>
      <translation>Arêtes vives masquées</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Hidden smooth edges</source>
      <translation>Arêtes de tangence masquées</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Hidden sewn edges</source>
      <translation>Arêtes cousues masquées</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Hidden outline edges</source>
      <translation>Arêtes de contour masquées</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Hidden isoparameters</source>
      <translation>Isoparamètres masqués</translation>
    </message>
    <message>
      <location line="+17"/>
      <source>Project shapes</source>
      <translation>Projeter les formes</translation>
    </message>
  </context>
  <context>
    <name>Drawing_NewPage</name>
    <message>
      <source>A0 landscape</source>
      <translation type="obsolete">A0 paysage</translation>
    </message>
    <message>
      <source>Insert new A0 landscape drawing</source>
      <translation type="obsolete">Insérer une feuille A0 paysage</translation>
    </message>
    <message>
      <source>A1 landscape</source>
      <translation type="obsolete">A1 paysage</translation>
    </message>
    <message>
      <source>Insert new A1 landscape drawing</source>
      <translation type="obsolete">Insérer une feuille A1 paysage</translation>
    </message>
    <message>
      <source>A2 landscape</source>
      <translation type="obsolete">A2 paysage</translation>
    </message>
    <message>
      <source>Insert new A2 landscape drawing</source>
      <translation type="obsolete">Insérer une feuille A2 paysage</translation>
    </message>
    <message>
      <source>A3 landscape</source>
      <translation type="obsolete">A3 Paysage</translation>
    </message>
    <message>
      <source>Insert new A3 landscape drawing</source>
      <translation type="obsolete">Insère une nouvelle feuille A3 paysage</translation>
    </message>
    <message>
      <source>A4 landscape</source>
      <translation type="obsolete">A4 paysage</translation>
    </message>
    <message>
      <source>Insert new A4 landscape drawing</source>
      <translation type="obsolete">Insérer une feuille A4 paysage</translation>
    </message>
    <message>
      <source>Insert new A%1 landscape drawing</source>
      <translation type="obsolete">Insérer une nouvelle feuille A%1 paysage</translation>
    </message>
    <message>
      <source>A%1 landscape</source>
      <translation type="obsolete">A%1 paysage</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="-298"/>
      <source>Landscape</source>
      <translation type="unfinished">Paysage</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Portrait</source>
      <translation type="unfinished">Portrait</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>%1%2 %3</source>
      <translation type="unfinished">%1 %2 %3</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Insert new %1%2 %3 drawing</source>
      <translation type="unfinished">Insérer le nouveau %1 %2 %3 dessin</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location line="-124"/>
      <location line="+426"/>
      <source>Choose an SVG file to open</source>
      <translation>Choisir un fichier SVG à ouvrir</translation>
    </message>
    <message>
      <location filename="../../AppDrawingGuiPy.cpp" line="+64"/>
      <location line="+30"/>
      <location filename="../../ViewProviderPage.cpp" line="+139"/>
      <source>Drawing viewer</source>
      <translation>Visionneuse de mise en plan</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="-425"/>
      <location line="+426"/>
      <source>Scalable Vector Graphics (*.svg *.svgz)</source>
      <translation>Fichier vectoriel SVG (*.svg *.svgz)</translation>
    </message>
    <message>
      <location line="-227"/>
      <location line="+51"/>
      <location line="+45"/>
      <location line="+177"/>
      <source>Wrong selection</source>
      <translation>Mauvaise sélection</translation>
    </message>
    <message>
      <location line="-272"/>
      <location line="+51"/>
      <source>Select a Part object.</source>
      <translation>Sélectionnez un objet pièce.</translation>
    </message>
    <message>
      <location line="-45"/>
      <location line="+51"/>
      <location line="+76"/>
      <location line="+45"/>
      <location line="+42"/>
      <source>No page to insert</source>
      <translation>Aucune page pour insérer</translation>
    </message>
    <message>
      <location line="-213"/>
      <location line="+127"/>
      <location line="+45"/>
      <location line="+42"/>
      <source>Create a page to insert.</source>
      <translation>Créer une page à insérer.</translation>
    </message>
    <message>
      <location line="-163"/>
      <source>Create a page to insert views into.</source>
      <translation>Crée une feuille pour y insérer des vues</translation>
    </message>
    <message>
      <location line="+38"/>
      <location line="+177"/>
      <source>Select one Page object.</source>
      <translation>Sélectionnez un objet Page.</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>SVG(*.svg)</source>
      <translation>SVG (*.svg)</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>All Files (*.*)</source>
      <translation>Tous les fichiers (*.*)</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Export page</source>
      <translation>Exporter la page</translation>
    </message>
    <message>
      <location filename="../../ViewProviderPage.cpp" line="-27"/>
      <source>Show drawing</source>
      <translation>Afficher la mise en plan</translation>
    </message>
    <message>
      <source>Front</source>
      <translation type="obsolete">Frontal</translation>
    </message>
    <message>
      <source>Back</source>
      <translation type="obsolete">Arrière</translation>
    </message>
    <message>
      <source>Right</source>
      <translation type="obsolete">Droit</translation>
    </message>
    <message>
      <source>Left</source>
      <translation type="obsolete">Gauche</translation>
    </message>
    <message>
      <source>Top</source>
      <translation type="obsolete">Dessus</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation type="obsolete">Dessous</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.cpp" line="+45"/>
      <location line="+908"/>
      <source>Make axonometric...</source>
      <translation type="unfinished">Rendre axonométrique...</translation>
    </message>
    <message>
      <location line="-907"/>
      <location line="+908"/>
      <source>Edit axonometric settings...</source>
      <translation type="unfinished">Modifier les paramètres axonométriques...</translation>
    </message>
    <message>
      <location line="-907"/>
      <location line="+908"/>
      <source>Make orthographic</source>
      <translation type="unfinished">Faire orthographique</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>Drawing</source>
      <translation>Mise en plan</translation>
    </message>
  </context>
</TS>
